@@ -1,8 +1,9 @@
 import cfdm
 
-from ...constants import _stash2standard_name
-from ...functions import _DEPRECATION_ERROR_ATTRIBUTE, load_stash2standard_name
-from ...umread_lib.umfile import File, Rec
+from cf.constants import _stash2standard_name
+from cf.functions import _DEPRECATION_ERROR_ATTRIBUTE, load_stash2standard_name
+from cf.umread_lib.umfile import File, Rec
+
 from .abstract import Array
 
 
