@@ -88,7 +88,7 @@ class read(cfdm.read):
     the end of the Python session, at which time it is automatically
     deleted. The CDL file may omit data array values (as would be the
     case, for example, if the file was created with the ``-h`` or
-    ``-c`` option to ``ncdump``), in which case the the relevant
+    ``-c`` option to ``ncdump``), in which case the relevant
     constructs in memory will be created with data with all missing
     values.
 
@@ -316,6 +316,10 @@ class read(cfdm.read):
 
             .. versionadded:: 3.17.0
 
+        {{read store_dataset_shards: `bool`, optional}}
+
+            .. versionadded:: 3.19.0
+
         {{read cfa: `dict`, optional}}
 
             .. versionadded:: 3.15.0
@@ -328,6 +332,10 @@ class read(cfdm.read):
 
             .. versionadded:: 3.17.0
 
+        {{read group_dimension_search: `str`, optional}}
+
+            .. versionadded:: 3.19.0
+
         umversion: deprecated at version 3.0.0
             Use the *um* parameter instead.
 
@@ -434,6 +442,7 @@ class read(cfdm.read):
         warn_valid=False,
         dask_chunks="storage-aligned",
         store_dataset_chunks=True,
+        store_dataset_shards=True,
         domain=False,
         cfa=None,
         cfa_write=None,
@@ -445,6 +454,7 @@ class read(cfdm.read):
         ignore_read_error=False,
         fmt=None,
         file_type=None,
+        group_dimension_search="closest_ancestor",
     ):
         """Read field or domain constructs from a dataset."""
         kwargs = locals()
@@ -725,7 +735,7 @@ class read(cfdm.read):
         # ------------------------------------------------------------
         # Try to read as a GRIB dataset
         #
-        # Not yet availabl. When (if!) the time comes, the framework
+        # Not yet available. When (if!) the time comes, the framework
         # will be:
         # ------------------------------------------------------------
         #
