@@ -840,6 +840,28 @@ class DimensionCoordinateTest(unittest.TestCase):
         d._custom["direction"] = None
         self.assertTrue(d[0].direction())
 
+    def test_DimensionCoordinate_to_units(self):
+        """Test DimensionCoordinate.to_units."""
+        f = cf.example_field(0)
+        d = f.dimension_coordinate("X")
+        d = d[:2]
+        self.assertEqual(d.period().Units, cf.Units("degrees_east"))
+
+        e = d.to_units("rad")
+        self.assertIsInstance(e, d.__class__)
+        self.assertEqual(e.Units, cf.Units("rad"))
+        self.assertTrue(np.allclose(e.array, [0.39269908, 1.17809725]))
+        self.assertEqual(e.period().Units, cf.Units("rad"))
+
+        self.assertIsNone(e.to_units("degrees_east", inplace=True))
+        self.assertEqual(e.Units, cf.Units("degrees_east"))
+        self.assertTrue(np.allclose(e.array, [22.5, 67.5]))
+        self.assertTrue(np.allclose(e.period().array, d.period().array))
+
+        # Non-equivalent units
+        with self.assertRaises(ValueError):
+            e.to_units("degC")
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
