@@ -1,13 +1,5 @@
-from ctypes.util import find_library
-
 from cfunits import Units as cfUnits
 
-_libpath = find_library("udunits2")
-if _libpath is None:
-    raise FileNotFoundError(
-        "cf requires UNIDATA UDUNITS-2. Can't find the 'udunits2' library."
-    )
-
 
 class Units:
     """Store, combine and compare physical units and convert numeric
